@@ -1,7 +1,7 @@
 
 /*
  *  agCgi.c
- *  $Id: agCgi.c,v 4.1 2005/01/01 00:12:17 bkorb Exp $
+ *  $Id: agCgi.c,v 4.6 2005/07/27 17:26:31 bkorb Exp $
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
@@ -9,7 +9,7 @@
  */
 
 /*
- *  AutoGen-cgi copyright 2001-2004 Bruce Korb
+ *  AutoGen-cgi copyright 2001-2005 Bruce Korb
  *
  *  AutoGen-cgi is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -24,8 +24,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 typedef struct {
@@ -77,9 +77,13 @@ static const char zOops[] =
 "Content-type: text/plain\n\n"
 "AutoGen form processing error:\n";
 
-static char* parseInput( char* pzSrc, int len );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static char*
+parseInput( char* pzSrc, int len );
+/* = = = END-STATIC-FORWARD = = = */
 
-EXPORT void
+LOCAL void
 loadCgi( void )
 {
     /*
@@ -115,7 +119,7 @@ loadCgi( void )
      */
     {
         tNameMap* pNM = nameValueMap;
-        tNameIdx  ix  = 0;
+        tNameIdx  ix  = (tNameIdx)0;
 
         do  {
             static char zNUL[1] = "";
@@ -161,7 +165,7 @@ loadCgi( void )
     }
 
     pBaseCtx->lineNo     = 1;
-    pBaseCtx->pzFileName = "@@ CGI Definitions @@";
+    pBaseCtx->pzCtxFname = "@@ CGI Definitions @@";
     pBaseCtx->pzScan     = pBaseCtx->pzData;
 }
 
