@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expPrint.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: expPrint.c,v 4.4 2005/06/07 22:26:43 bkorb Exp $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -10,7 +10,7 @@
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,23 +25,32 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
-STATIC sigjmp_buf printJumpEnv;
-STATIC void   printFault( int sig );
-STATIC ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
+static sigjmp_buf printJumpEnv;
+static void   printFault( int sig );
+static ssize_t safePrintf( char** pzBuf, char* pzFmt, void** argV );
 tSCC pzFormatName[] = "format";
 
-STATIC void
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+printFault( int sig );
+
+static ssize_t
+safePrintf( char** ppzBuf, char* pzFmt, void** argV );
+/* = = = END-STATIC-FORWARD = = = */
+
+static void
 printFault( int sig )
 {
     siglongjmp( printJumpEnv, sig );
 }
 
 
-STATIC ssize_t
+static ssize_t
 safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 {
     tSCC zBadArgs[]  = "Bad args to sprintf";
@@ -97,7 +106,7 @@ safePrintf( char** ppzBuf, char* pzFmt, void** argV )
 }
 
 
-EXPORT SCM
+LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist )
 {
     SCM     res;
