@@ -1,8 +1,9 @@
 
 /*
- *  Time-stamp:      "2005-01-23 15:31:08 bkorb"
+ *  Time-stamp:      "2005-09-20 19:32:35 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 4.5 2005/01/24 00:00:35 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 4.15 2005/10/02 16:34:30 bkorb Exp $
+ *  Time-stamp:      "2005-02-14 05:59:50 bkorb"
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
@@ -24,8 +25,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -54,20 +55,24 @@
 #ifndef AUTOGEN_AUTOOPTS_H
 #define AUTOGEN_AUTOOPTS_H
 
-#define __EXTENSIONS__
-
-#include "config.h"
 #include "compat/compat.h"
-#include <sys/param.h>
-#include <sys/wait.h>
-#include <time.h>
-#include <utime.h>
 
 #define AO_NAME_LIMIT    127
 #define AO_NAME_SIZE     (AO_NAME_LIMIT + 1)
+
 #ifndef MAXPATHLEN
-#  define MAXPATHLEN     4096
+#  ifdef PATH_MAX
+#    define MAXPATHLEN   PATH_MAX
+#  else
+#    define MAXPATHLEN   4096
+#  endif
+#else
+#  if defined(PATH_MAX) && (PATH_MAX > MAXPATHLEN)
+#     undef  MAXPATHLEN
+#     define MAXPATHLEN  PATH_MAX
+#  endif
 #endif
+
 #undef  EXPORT
 #define EXPORT
 
@@ -84,6 +89,8 @@
 typedef int tDirection;
 #define DIRECTION_PRESET  -1
 #define DIRECTION_PROCESS  1
+#define DIRECTION_CALLED   0
+
 #define PROCESSING(d)     ((d)>0)
 #define PRESETTING(d)     ((d)<0)
 
@@ -107,11 +114,11 @@ typedef int tSuccess;
 #define HADGLITCH( p )     ((p) >  SUCCESS)
 
 /*
- *  The pager state is used by doPagedUsage() procedure.
+ *  The pager state is used by optionPagedUsage() procedure.
  *  When it runs, it sets itself up to be called again on exit.
  *  If, however, a routine needs a child process to do some work
  *  before it is done, then 'pagerState' must be set to
- *  'PAGER_STATE_CHILD' so that doPagedUsage() will not try
+ *  'PAGER_STATE_CHILD' so that optionPagedUsage() will not try
  *  to run the pager program before its time.
  */
 typedef enum {
@@ -137,13 +144,12 @@ typedef enum {
 
 typedef struct {
     tOptDesc*  pOD;
+    tCC*       pzOptArg;
     tUL        flags;
     teOptType  optType;
-    int        argType;
-    tCC*       pzOptArg;
 } tOptState;
-#define OPTSTATE_INITIALIZER \
-    { NULL, OPTST_DEFINED, TOPT_UNDEFINED, 0, NULL }
+#define OPTSTATE_INITIALIZER(st) \
+    { NULL, NULL, OPTST_ ## st, TOPT_UNDEFINED }
 
 #define TEXTTO_TABLE \
         _TT_( LONGUSAGE ) \
@@ -163,6 +169,7 @@ typedef struct {
     tCC*    pzKey;
     tCC*    pzKeyL;
     tCC*    pzBool;
+    tCC*    pzNest;
     tCC*    pzOpt;
     tCC*    pzNo;
     tCC*    pzBrk;
@@ -255,6 +262,36 @@ typedef struct {
     || (((_flg) & (OPTST_DISABLED|OPTST_DISABLE_TWICE))  ==     \
                   (OPTST_DISABLED|OPTST_DISABLE_TWICE)  ))
 
+/*
+ *  text_mmap structure.  Only active on platforms with mmap(2).
+ */
+#ifdef HAVE_SYS_MMAN_H
+#  include <sys/mman.h>
+#else
+#  ifndef  PROT_READ
+#   define PROT_READ    0x01
+#  endif
+#  ifndef  PROT_WRITE
+#   define PROT_WRITE   0x02
+#  endif
+#  ifndef  MAP_SHARED
+#   define MAP_SHARED   0x01
+#  endif
+#  ifndef  MAP_PRIVATE
+#   define MAP_PRIVATE  0x02
+#  endif
+#endif
+
+#ifndef MAP_FAILED
+#  define  MAP_FAILED   ((void*)-1)
+#endif
+
+#ifndef  _SC_PAGESIZE
+# ifdef  _SC_PAGE_SIZE
+#  define _SC_PAGESIZE _SC_PAGE_SIZE
+# endif
+#endif
+
 /*
  *  Define and initialize all the user visible strings.
  *  We do not do translations.  If translations are to be done, then
@@ -268,7 +305,7 @@ typedef struct {
  */
 extern FILE* option_usage_fp;
 
-extern tOptProc doVersion, doPagedUsage, doLoadOpt;
+extern tOptProc optionPrintVersion, optionPagedUsage, optionLoadOpt;
 
 #define LOCAL static
 #include "proto.h"
